# Mattermost backend for Errbot

This is the Mattermost backend for errbot.

# Documentation

Visit the [official documentation](https://err-backend-mattermost.readthedocs.io/) where you'll find information on the following topics:
 - Installation
 - Configuration
 - User Guide
 - Developer Guide

